==> rdblib-2.5.6-arm64-linux.tar.gz: rdblib-2.5.6-arm64-linux/interface/c/riegl/rdb/version.h <==
/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \file    version.h
 * \author  RIEGL LMS GmbH, Austria
 * \brief   RDB library API version
 * \version 2020-01-16/AW: Initial version
 *
 *******************************************************************************
 */

#ifndef RIEGL_RDB_VERSION_H
#define RIEGL_RDB_VERSION_H

//---< MACROS >-----------------------------------------------------------------

#define RIEGL_RDB_INTERFACE_MAJOR 2
#define RIEGL_RDB_INTERFACE_MINOR 5
#define RIEGL_RDB_INTERFACE_MICRO 6

//---< CONSTANTS >--------------------------------------------------------------

const char* const RIEGL_RDB_INTERFACE_NAME    = "RDB Interface";
const char* const RIEGL_RDB_INTERFACE_VERSION = "2.5.6-a3f98410 (C, Sep 10 2025, 12:36:14)";

#endif // RIEGL_RDB_VERSION_H

==> rdblib-2.5.7-arm64-linux.tar.gz: rdblib-2.5.7-arm64-linux/interface/c/riegl/rdb/version.h <==
/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \file    version.h
 * \author  RIEGL LMS GmbH, Austria
 * \brief   RDB library API version
 * \version 2020-01-16/AW: Initial version
 *
 *******************************************************************************
 */

#ifndef RIEGL_RDB_VERSION_H
#define RIEGL_RDB_VERSION_H

//---< MACROS >-----------------------------------------------------------------

#define RIEGL_RDB_INTERFACE_MAJOR 2
#define RIEGL_RDB_INTERFACE_MINOR 5
#define RIEGL_RDB_INTERFACE_MICRO 7

//---< CONSTANTS >--------------------------------------------------------------

const char* const RIEGL_RDB_INTERFACE_NAME    = "RDB Interface";
const char* const RIEGL_RDB_INTERFACE_VERSION = "2.5.7-0bbe6e0f (C, Nov 21 2025, 12:53:27)";

#endif // RIEGL_RDB_VERSION_H
